# Extra encodings for Python 
#### Full documentation available at [sites.google.com](https://sites.google.com/view/extra-encodings-docs/)
------


## Update 1.4
---
Added Gui with tkinter\
Finshed ichor\
Added a class for a 2 way dict in classsstuff.py so check that out\
Added a class to make an Encoding in ciphers.py, if you want to know how to use\
Decided to delete encodingsbeta  and instead use beta releases


## Plans:
----
Add a function that makes a encoding\
Add documentation\
Adding more encodings/decodings\
Make my TwoWayDict class more feature rich. (1/3 finshed)\
Add Binary encodings


## Notes
----
This is my first ever package (Which no one has ever installed)\
Ichor is not available in GUI due to  dictionary)'s being stubborn\
Currently we only support all characters on a US keyboard for all encoding types and a computer that runs a standard os like Win32/64 , macOS (Not tested), Linux Debian,Ubuntu and distros based on them.

## Planned and Implmented Decodings and encodings:
----
Ichor\
Gen2\
LTF-64\
GTX2\
LGC(To  be added to encoders 1.4.6 and made in ciphers.py 1.4.5)\

## How to import
----
```p
    import extraEncodings
    #to import all
    from extraEncodings import *
    #to import encoder
    from extraEncodings import encodings
    #to import  classes and encoder making
    from extraEncodings import classstuff
    #To run the script that shows you how to use the class Encoding(). For now there is no documentation for anything other than this.
    from extraEncodings import CreateAnEncoding
    #to import  raw encoders
    from extraEncodings import ciphers
    #to import gui
    from extraEncodings import encodingsGui

```
 